@@ -3,7 +3,7 @@
 #' Fit keyATM models.
 #'
 #' @param docs texts read via [keyATM_read()].
-#' @param model keyATM model: \code{base}, \code{covariates}, \code{dynamic}, and \code{label}.
+#' @param model keyATM model: \code{base}, \code{covariates}, and \code{dynamic}.
 #' @param no_keyword_topics the number of regular topics.
 #' @param keywords a list of keywords.
 #' @param model_settings a list of model specific settings (details are in the online documentation).
@@ -26,9 +26,10 @@
 #'            \item \emph{P}: For the dynamic model. The state transition probability.
 #'      }
 #'      \item \strong{parallel_init}: Parallelize processes to speed up initialization. Default is \code{FALSE}. Please `plan()` before use this feature.
+#'      \item \strong{resume}: The resume argument is used to save and load the intermediate results of the keyATM fitting process, allowing you to resume the fitting from a previous state. The default value is `NULL` (do not resume).
 #' }
 #' @param keep a vector of the names of elements you want to keep in output.
-#' 
+#'
 #' @return A \code{keyATM_output} object containing:
 #'   \describe{
 #'     \item{keyword_k}{number of keyword topics}
@@ -67,22 +68,6 @@
 #'   out <- keyATM(docs = keyATM_docs, model = "base",
 #'                 no_keyword_topics = 5, keywords = bills_keywords)
 #'
-#'   # keyATM Covariates
-#'   bills_cov <- as.data.frame(keyATM_data_bills$cov)
-#'   out <- keyATM(docs = keyATM_docs, model = "covariates",
-#'                 no_keyword_topics = 5, keywords = bills_keywords,
-#'                 model_settings = list(covariates_data = bills_cov,
-#'                                       covariates_formula = ~ RepParty))
-#'
-#'   # keyATM Dynamic
-#'   bills_time_index <- keyATM_data_bills$time_index
-#'   # Time index should start from 1 and increase by 1
-#'   bills_time_index <- as.integer(bills_time_index - 100)
-#'   out <- keyATM(docs = keyATM_docs, model = "dynamic",
-#'                 no_keyword_topics = 5, keywords = bills_keywords,
-#'                 model_settings = list(num_states = 5,
-#'                                       time_index = bills_time_index))
-#'
 #'   # Visit our website for full examples: https://keyatm.github.io/keyATM/
 #' }
 #'
@@ -95,23 +80,41 @@ keyATM <- function(docs, model, no_keyword_topics,
   if (length(keep) != 0)
     check_arg_type(keep, "character")
 
-  model <- full_model_name(model, type="keyATM")
+  model_name <- full_model_name(model, type = "keyATM")
   if (is.null(options$seed))
-    options$seed <- floor(stats::runif(1)*1e5)
+    options$seed <- floor(stats::runif(1) * 1e5)
   set.seed(options$seed)
 
-  # Fit keyATM
-  fitted <- keyATM_fit(
-                       docs, model, no_keyword_topics,
-                       keywords, model_settings, priors, options
-                      )
+  # Check if there is a resume object
+  if ("resume" %in% names(options) && fs::file_exists(options$resume)) {
+    resume <- TRUE
+    fitted <- fitted_load(options$resume)
+    exists_iter <- fitted$used_iter
+    fitted <- fitted_update_iterations(fitted, options)
+    fitted <- keyATM_fit(fitted, resume = TRUE)
+    used_iter <- get_used_iter(fitted, resume, exists = exists_iter)
+  } else {
+    resume <- FALSE
+    initialized <- keyATM_initialize(
+      docs, model_name, no_keyword_topics,
+      keywords, model_settings, priors, options
+    )
+    fitted <- keyATM_fit(initialized)
+    used_iter <- get_used_iter(fitted, resume)
+  }
+
+  if ("resume" %in% names(options)) {  # first save or update
+    fitted_save(options$resume, fitted, model_name, used_iter)
+  }
 
   # 0 iterations
-  if (fitted$options$iterations == 0)
-    return(fitted) 
+  if (fitted$options$iterations == 0) {
+    cli::cli_alert_info("`options$iterations` is 0. keyATM returns an initialized object.")
+    return(fitted)
+  }
 
   # Get output
-  out <- keyATM_output(fitted, keep)
+  out <- keyATM_output(fitted, keep, used_iter)
 
   return(out)
 }
@@ -165,22 +168,6 @@ keyATM <- function(docs, model, no_keyword_topics,
 #'   out <- weightedLDA(docs = keyATM_docs, model = "base",
 #'                      number_of_topics = 5)
 #'
-#'   # Weighted LDA Covariates
-#'   bills_cov <- as.data.frame(keyATM_data_bills$cov)
-#'   out <- weightedLDA(docs = keyATM_docs, model = "covariates",
-#'                      number_of_topics = 5,
-#'                      model_settings = list(covariates_data = bills_cov,
-#'                                            covariates_formula = ~ RepParty))                   
-#'
-#'   # Weighted LDA Dynamic
-#'   bills_time_index <- keyATM_data_bills$time_index
-#'   # Time index should start from 1 and increase by 1
-#'   bills_time_index <- as.integer(bills_time_index - 100)
-#'   out <- weightedLDA(docs = keyATM_docs, model = "dynamic",
-#'                      number_of_topics = 5,
-#'                      model_settings = list(num_states = 5,
-#'                                            time_index = bills_time_index))
-#'
 #'   # Visit our website for full examples: https://keyatm.github.io/keyATM/
 #' }
 #'
@@ -193,23 +180,42 @@ weightedLDA <- function(docs, model, number_of_topics,
   if (length(keep) != 0)
     check_arg_type(keep, "character")
 
-  model <- full_model_name(model, type="lda")
+  model_name <- full_model_name(model, type = "lda")
+  if (is.null(options$seed))
+    options$seed <- floor(stats::runif(1) * 1e5)
+  set.seed(options$seed)
 
-  # Fit keyATM
-  fitted <- keyATM_fit(
-                       docs, model, number_of_topics,
-                       keywords = list(),
-                       model_settings = model_settings,
-                       priors = priors,
-                       options = options
-                      )
+ # Check if there is a resume object
+  if ("resume" %in% names(options) && fs::file_exists(options$resume)) {
+    resume <- TRUE
+    fitted <- fitted_load(options$resume)
+    exists_iter <- fitted$used_iter
+    fitted <- fitted_update_iterations(fitted, options)
+    fitted <- keyATM_fit(fitted, resume = TRUE)
+    used_iter <- get_used_iter(fitted, resume, exists = exists_iter)
+  } else {
+    resume <- FALSE
+    initialized <- keyATM_initialize(
+      docs, model_name, number_of_topics,
+      keywords = list(), model_settings = model_settings,
+      priors = priors, options = options
+    )
+    fitted <- keyATM_fit(initialized)
+    used_iter <- get_used_iter(fitted, resume)
+  }
+
+  if ("resume" %in% names(options)) {
+    fitted_save(options$resume, fitted, model_name, used_iter)
+  }
 
   # 0 iterations
-  if (fitted$options$iterations == 0)
-    return(fitted) 
+  if (fitted$options$iterations == 0) {
+    cli::cli_alert_info("`options$iterations` is 0. keyATM returns an initialized object.")
+    return(fitted)
+  }
 
   # Get output
-  out <- keyATM_output(fitted, keep)
+  out <- keyATM_output(fitted, keep, used_iter)
   out$number_of_topics <- number_of_topics
   out$no_keyword_topics <- NULL
   out$keyword_k <- NULL
@@ -217,4 +223,48 @@ weightedLDA <- function(docs, model, number_of_topics,
   return(out)
 }
 
+# Resume related functions
+fitted_load <- function(filename) {
+  fitted <- readRDS(filename)
+  if (! "keyATM_resume" %in% class(fitted))
+    cli::cli_abort("The file is not a keyATM object.")
+  cli::cli_alert_success("The fitted model is loaded from {.file {filename}}.")
+  return(fitted)
+}
 
+fitted_update_iterations <- function(fitted, new_options) {
+  if (! "keyATM_resume" %in% class(fitted))
+    cli::cli_abort("The file is not a keyATM object.")
+  if (! "iterations" %in% names(new_options))
+    cli::cli_abort("The `options` argument must contain `iterations`.")
+  fitted$model$options$iterations <- fitted$model$options$iterations + new_options$iterations  # total after the fitting
+  fitted$model$options$iter_new <- new_options$iterations  # iterations to add
+  return(fitted)
+}
+
+fitted_save <- function(filename, fitted, model_name, used_iter) {
+  saveobj <- list(
+    model = fitted,
+    model_name = model_name,
+    used_iter = used_iter,
+    rand_state = .GlobalEnv$.Random.seed
+  )
+  class(saveobj) <- c("keyATM_resume", class(saveobj))
+  saveRDS(object = saveobj, file = filename)
+  cli::cli_alert_success("The fitted model is saved in {.file {filename}}.")
+}
+
+# Get indexes of used iterations
+get_used_iter <- function(fitted, resume, exists = NULL) {
+  thinning <- fitted$options$thinning
+  if (resume) {
+    exists_max <- max(exists)
+    total_iter <- (exists_max + 1):(fitted$options$iterations)
+    total_iter <- total_iter[(total_iter %% thinning == 0) | (total_iter == 1) | total_iter == max(total_iter)]
+    used_iter <- c(exists, total_iter)
+  } else {
+    total_iter <- 1:(fitted$options$iterations)
+    used_iter <- total_iter[(total_iter %% thinning == 0) | (total_iter == 1) | total_iter == max(total_iter)]
+  }
+  return(used_iter)
+}
\ No newline at end of file
